==> zrythm-0.8.200.tar.xz: zrythm-0.8.200/inc/gui/widgets/left_dock_edge.h <==
/*
 * gui/widgets/left_dock_edge.h - Main window widget
 *
 * Copyright (C) 2019 Alexandros Theodotou
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GUI_WIDGETS_LEFT_DOCK_EDGE_H__
#define __GUI_WIDGETS_LEFT_DOCK_EDGE_H__

#include <gtk/gtk.h>

#define LEFT_DOCK_EDGE_WIDGET_TYPE \
  (left_dock_edge_widget_get_type ())
G_DECLARE_FINAL_TYPE (
  LeftDockEdgeWidget,
  left_dock_edge_widget,
  Z, LEFT_DOCK_EDGE_WIDGET,
  GtkBox)

#define MW_LEFT_DOCK_EDGE \
  MW_CENTER_DOCK->left_dock_edge

typedef struct _InspectorWidget InspectorWidget;
typedef struct _VisibilityWidget VisibilityWidget;
typedef struct _FoldableNotebookWidget
  FoldableNotebookWidget;

typedef struct _LeftDockEdgeWidget
{
  GtkBox                   parent_instance;
  FoldableNotebookWidget * inspector_notebook;
  InspectorWidget *        inspector;
  VisibilityWidget *       visibility;
  GtkGestureMultiPress *   mp;
} LeftDockEdgeWidget;

void
left_dock_edge_widget_setup (
  LeftDockEdgeWidget * self);

#endif

==> zrythm-0.8.333.tar.xz: zrythm-0.8.333/inc/gui/widgets/left_dock_edge.h <==
/*
 * gui/widgets/left_dock_edge.h - Main window widget
 *
 * Copyright (C) 2019 Alexandros Theodotou
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GUI_WIDGETS_LEFT_DOCK_EDGE_H__
#define __GUI_WIDGETS_LEFT_DOCK_EDGE_H__

#include <gtk/gtk.h>

#define LEFT_DOCK_EDGE_WIDGET_TYPE \
  (left_dock_edge_widget_get_type ())
G_DECLARE_FINAL_TYPE (
  LeftDockEdgeWidget,
  left_dock_edge_widget,
  Z, LEFT_DOCK_EDGE_WIDGET,
  GtkBox)

#define MW_LEFT_DOCK_EDGE \
  MW_CENTER_DOCK->left_dock_edge

typedef struct _InspectorWidget InspectorWidget;
typedef struct _VisibilityWidget VisibilityWidget;
typedef struct _FoldableNotebookWidget
  FoldableNotebookWidget;
typedef struct _InspectorTrackWidget
  InspectorTrackWidget;
typedef struct _InspectorPluginWidget
  InspectorPluginWidget;

typedef struct _LeftDockEdgeWidget
{
  GtkBox                   parent_instance;
  FoldableNotebookWidget * inspector_notebook;
  //InspectorWidget *        inspector;
  VisibilityWidget *       visibility;
  GtkGestureMultiPress *   mp;

  /** For TracklistSelections. */
  InspectorTrackWidget *  track_inspector;

  /** For MixerSelections. */
  InspectorPluginWidget * plugin_inspector;
} LeftDockEdgeWidget;

void
left_dock_edge_widget_refresh (
  LeftDockEdgeWidget * self);

void
left_dock_edge_widget_setup (
  LeftDockEdgeWidget * self);

#endif
